tiled.adapters.excel.ExcelAdapter
=================================

.. currentmodule:: tiled.adapters.excel

.. autoclass:: ExcelAdapter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ExcelAdapter.__init__
      ~ExcelAdapter.authenticated_as
      ~ExcelAdapter.from_file
      ~ExcelAdapter.get
      ~ExcelAdapter.items
      ~ExcelAdapter.keys
      ~ExcelAdapter.new_variation
      ~ExcelAdapter.read
      ~ExcelAdapter.register_query
      ~ExcelAdapter.register_query_lazy
      ~ExcelAdapter.search
      ~ExcelAdapter.sort
      ~ExcelAdapter.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ExcelAdapter.access_policy
      ~ExcelAdapter.background_tasks
      ~ExcelAdapter.entries_stale_after
      ~ExcelAdapter.entries_stale_at
      ~ExcelAdapter.include_routers
      ~ExcelAdapter.items_indexer
      ~ExcelAdapter.keys_indexer
      ~ExcelAdapter.metadata
      ~ExcelAdapter.metadata_stale_after
      ~ExcelAdapter.metadata_stale_at
      ~ExcelAdapter.must_revalidate
      ~ExcelAdapter.principal
      ~ExcelAdapter.query_registry
      ~ExcelAdapter.structure_family
      ~ExcelAdapter.values_indexer
   
   